Index: uspace/lib/drv/include/ddf/driver.h
===================================================================
--- uspace/lib/drv/include/ddf/driver.h	(revision c06994673347954891a57710998cf1e087a59e8b)
+++ uspace/lib/drv/include/ddf/driver.h	(revision 1dc4a5e441cc195a33bd958ea4994dcd59141df0)
@@ -151,5 +151,5 @@
 extern int ddf_fun_add_match_id(ddf_fun_t *, const char *, int);
 
-extern int ddf_fun_add_to_class(ddf_fun_t *, const char *);
+extern int ddf_fun_add_to_category(ddf_fun_t *, const char *);
 
 #endif

Index: uspace/lib/drv/generic/driver.c
===================================================================
--- uspace/lib/drv/generic/driver.c	(revision c06994673347954891a57710998cf1e087a59e8b)
+++ uspace/lib/drv/generic/driver.c	(revision 1dc4a5e441cc195a33bd958ea4994dcd59141df0)
@@ -635,14 +635,14 @@
 }
 
 /** Add exposed function to class.
  *
  * Must only be called when the function is bound.
  */
-int ddf_fun_add_to_class(ddf_fun_t *fun, const char *class_name)
+int ddf_fun_add_to_category(ddf_fun_t *fun, const char *cat_name)
 {
 	assert(fun->bound == true);
 	assert(fun->ftype == fun_exposed);
 	
-	return devman_add_device_to_class(fun->handle, class_name);
+	return devman_add_device_to_category(fun->handle, cat_name);
 }
 
@@ -635,14 +635,14 @@
 }
 
-/** Add exposed function to class.
+/** Add exposed function to category.
  *
  * Must only be called when the function is bound.